jupyter_client: Jupyter protocol implementation and client libraries
====================================================================

Description
-----------

jupyter_client contains the reference implementation of the Jupyter
protocol. It also provides client and kernel management APIs for working
with kernels.

It also provides the jupyter kernelspec entrypoint for installing
kernelspecs for use with Jupyter frontends.
